@@ -36,19 +36,33 @@ def handler(event, context):
             next_token = None
             
             while not found_recipe:
-                response = ib_client.list_image_recipes(
-                    owner='Self',
-                    filters=[
-                        {
-                            'name': 'name',
-                            'values': [
-                                recipe_name,
-                            ]
-                        },
-                    ],
-                    maxResults=25, # for some reason, boto does the filtering client-side.
-                    nextToken=next_token
-                )
+                if next_token:
+                    response = ib_client.list_image_recipes(
+                        owner='Self',
+                        filters=[
+                            {
+                                'name': 'name',
+                                'values': [
+                                    recipe_name,
+                                ]
+                            },
+                        ],
+                        maxResults=25, # for some reason, boto does the filtering client-side.
+                        nextToken=next_token
+                    )
+                else:
+                    response = ib_client.list_image_recipes(
+                        owner='Self',
+                        filters=[
+                            {
+                                'name': 'name',
+                                'values': [
+                                    recipe_name,
+                                ]
+                            },
+                        ],
+                        maxResults=25 # for some reason, boto does the filtering client-side.
+                    )
                 
                 if 'imageRecipeSummaryList' in response and len(response['imageRecipeSummaryList']) > 0:
                     found_recipe = True
